package Sah::Schemas::CPANMeta;

1;
# ABSTRACT: Sah schemas for CPAN Meta specification

__END__

=pod

=encoding UTF-8

=head1 NAME

Sah::Schemas::CPANMeta - Sah schemas for CPAN Meta specification

=head1 VERSION

This document describes version 0.003 of Sah::Schemas::CPANMeta (from Perl distribution Sah-Schemas-CPANMeta), released on 2017-01-08.

=head1 SYNOPSIS

=head1 HOMEPAGE

Please visit the project's homepage at L<https://metacpan.org/release/Sah-Schemas-CPANMeta>.

=head1 SOURCE

Source repository is at L<https://github.com/perlancar/perl-Sah-Schemas-CPANMeta>.

=head1 BUGS

Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Sah-Schemas-CPANMeta>

When submitting a bug or request, please include a test-file or a
patch to an existing test-file that illustrates the bug or desired
feature.

=head1 SEE ALSO

L<Sah::Schemas::CPAN>

L<CPAN::Meta>, L<CPAN::Meta::Validator>

L<Sah> - specification

L<Data::Sah>

=head1 AUTHOR

perlancar <perlancar@cpan.org>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2017 by perlancar@cpan.org.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut
